@@ -1,5 +1,5 @@
 /*
- * $Id: dbdimp.h 87 2004-02-19 16:49:09Z jurl $
+ * $Id: dbdimp.h 135 2004-02-23 05:37:56Z jurl $
  * Copyright (c) 1997-2001 Jeff Urlwin
  * portions Copyright (c) 1997  Thomas K. Wenrich
  * portions Copyright (c) 1994,1995,1996  Tim Bunce
@@ -172,4 +172,7 @@ struct phs_st {  	/* scalar placeholder EXPERIMENTAL	*/
 #define dbd_bind_ph		odbc_bind_ph
 #define dbd_error		odbc_error
 #define dbd_discon_all		odbc_discon_all
+#define dbd_st_tables		odbc_st_tables
+#define dbd_st_primary_keys	odbc_st_primary_keys
+#define dbd_db_execdirect	odbc_db_execdirect
 /* end */
